package com.lilosoft.api.service;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.json.JSONUtil;
import com.lilosoft.api.api.RobotApi;
import com.lilosoft.api.bean.RobotCaseRecord;
import com.lilosoft.core.model.JsonResult;
import com.lilosoft.core.utils.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.*;

@Component
public class ScheduledService {

    /**
     * 日志对象
     */
    public Logger logger = LoggerFactory.getLogger(getClass());

    @Value("${scheduled.monitorOpen}")
    private String monitorOpen;

    @Value("${api.mq}")
    private String mq;

    @Autowired
    private RobotApi robotApi;

    @Autowired
    private ApplyService applyService;

    @Scheduled(cron="${scheduled.monitorCron}")
    public void serverMonitorSchedule() {
        if("true".equals(monitorOpen)){
            JsonResult jsonResult = robotApi.queryRecordList(mq, "1");
            if(jsonResult.isSuccess()){
                Object obj = jsonResult.getObj();
                if(obj != null){
                    List<Map<String, Object>> list =  new ArrayList<>();
                    CollUtil.addAll(list, obj);
                    RobotCaseRecord bean = null;
                    try {
                        for (Map<String, Object> map : list) {
                            bean = BeanUtil.toBean(map, RobotCaseRecord.class);
                            HashMap<String, Object> entries = JSONUtil.toBean(bean.getContent(), HashMap.class);
                            String apply = applyService.webApply(entries);
                            if(ObjectUtils.isEmpty(apply)){
                                bean.setSendFlag("2");
                                bean.setMsg("success");
                            } else {
                                bean.setSendFlag("1");
                                bean.setMsg(apply);
                            }
                            bean.setUpdateTime(new Date());
                            robotApi.saveRecord(bean);
                        }
                    } catch (Exception e) {
                        if(bean != null){
                            bean.setUpdateTime(new Date());
                            bean.setMsg(Arrays.toString(e.getStackTrace()));
                            robotApi.saveRecord(bean);
                        }
                        logger.error(Arrays.toString(e.getStackTrace()));
                        e.printStackTrace();
                    }
                }
            } else {
                logger.error("读取推送数据失败:" + jsonResult.getMsg());
            }
        }
    }
}
