package com.lilosoft.core.filter.xss;

import org.springframework.util.StringUtils;

import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;

/**
 * XSS 过滤器
 * @author yanjie
 * @Date 2018年11月12日
 */
public class XssAndSqlFilter implements Filter {
 
	FilterConfig filterConfig = null;

	private String ignoreUrl;
	private boolean isConvert = false;

    public void init(FilterConfig filterConfig) throws ServletException {
        this.filterConfig = filterConfig;
        setIgnoreUrl(filterConfig.getInitParameter("ignoreUrl"));
        if(filterConfig.getInitParameter("isConvert") != null) {
        	setConvert("true".equals(filterConfig.getInitParameter("isConvert")));
        }
    }

    public void destroy() {
        this.filterConfig = null;
    }

    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
        HttpServletRequest httpServletRequest = (HttpServletRequest) request;
        String servletPath = httpServletRequest.getServletPath();

//        System.out.println(">>>>>>>>>>>>   "+servletPath);
        if(ignoreUrl !=null && !"".equals(ignoreUrl)){
            String[] wsPaths= StringUtils.split(ignoreUrl, ",");
            boolean ignore = false;
            for(String waPath : wsPaths){
                waPath = StringUtils.replace("\t", "",waPath);
                waPath = StringUtils.replace("\n", "",waPath);
                waPath = waPath.trim();
                if(servletPath.startsWith(waPath)){
                	ignore = true;
                	break;
                }
            }
            if(ignore) {
            	chain.doFilter(request, response);
            }else {
            	chain.doFilter(new XssAndSqlHttpServletRequestWrapper((HttpServletRequest) request,isConvert), response);
            }
        }else {
        	chain.doFilter(new XssAndSqlHttpServletRequestWrapper((HttpServletRequest) request,isConvert), response);
        }
    }

    public final String getIgnoreUrl() {
        return ignoreUrl;
    }

    public final void setIgnoreUrl(String ignoreUrl) {
        this.ignoreUrl = ignoreUrl;
    }

	public boolean isConvert() {
		return isConvert;
	}

	public void setConvert(boolean isConvert) {
		this.isConvert = isConvert;
	}
}